@@ -15,13 +15,13 @@ NULL
 #' @describeIn node_census Returns a census of the ties in a network.
 #'   For directed networks, out-ties and in-ties are bound together.
 #' @examples
-#' task_eg <- to_named(to_uniplex(ison_algebra, "task_tie"))
+#' task_eg <- manynet::to_named(manynet::to_uniplex(manynet::ison_algebra, "task_tie"))
 #' (tie_cen <- node_tie_census(task_eg))
 #' @export
-node_tie_census <- function(object){
-  object <- as_igraph(object)
+node_tie_census <- function(.data){
+  object <- manynet::as_igraph(.data)
   edge_names <- igraph::edge_attr_names(object)
-  if (is_directed(object)) {
+  if (manynet::is_directed(object)) {
     mat <- vector()
     if (length(edge_names) > 0) {
       for (e in edge_names) {
@@ -44,7 +44,7 @@ node_tie_census <- function(object){
         mat <- rbind(mat, rc)
       }
   }
-  if(is_labelled(object) & is_directed(object))
+  if(manynet::is_labelled(object) & manynet::is_directed(object))
     if(length(edge_names) > 0){
       rownames(mat) <- apply(expand.grid(c(paste0("from", igraph::V(object)$name),
                                            paste0("to", igraph::V(object)$name)),
@@ -65,8 +65,8 @@ node_tie_census <- function(object){
 #' @examples 
 #' (triad_cen <- node_triad_census(task_eg))
 #' @export
-node_triad_census <- function(object){
-  x <- as_igraph(object)
+node_triad_census <- function(.data){
+  x <- manynet::as_igraph(.data)
   out <- vector() # This line intialises an empty vector
   for (i in seq_len(igraph::vcount(x))) { # For each (i) in 
     nb.wi <- igraph::graph.neighborhood(x,
@@ -88,9 +88,9 @@ node_triad_census <- function(object){
                      "021U", "021C", "111D", "111U",
                      "030T", "030C", "201", "120D",
                      "120U", "120C", "210", "300")
-  if (!is_directed(object)) out <- out[, c(1, 2, 3, 11, 15, 16)]
+  if (!manynet::is_directed(.data)) out <- out[, c(1, 2, 3, 11, 15, 16)]
   rownames(out) <- igraph::V(x)$name
-  make_node_motif(out, object)
+  make_node_motif(out, .data)
 }
 
 #' @describeIn node_census Returns a census of nodes' positions
@@ -127,17 +127,17 @@ node_triad_census <- function(object){
 #'  \emph{Applied Network Science} 2(1):13. 
 #'  \doi{10.1007/s41109-017-0027-2}.
 #' @examples 
-#' node_quad_census(ison_southern_women)
+#' node_quad_census(manynet::ison_southern_women)
 #' @export
-node_quad_census <- function(object){
+node_quad_census <- function(.data){
   if (!("oaqc" %in% rownames(utils::installed.packages()))) {
     message("Please install package `{oaqc}`.")
   } else {
-    graph <- object %>% as_tidygraph() %E>% 
+    graph <- .data %>% manynet::as_tidygraph() %E>% 
       as.data.frame()
     out <- oaqc::oaqc(graph)[[1]]
     out <- out[-1,]
-    rownames(out) <- node_names(object)
+    rownames(out) <- manynet::node_names(.data)
     colnames(out) <- c("E4", # co-K4
                        "I41","I40", # co-diamond
                        "H4", # co-C4
@@ -149,29 +149,29 @@ node_quad_census <- function(object){
                        "04", # C4
                        "Z42","Z43", # diamond
                        "X4") # K4
-    if(is_twomode(object)) out <- out[,-c(8,9,14,15,16,18,19,20)]
-    make_node_motif(out, object)
+    if(manynet::is_twomode(.data)) out <- out[,-c(8,9,14,15,16,18,19,20)]
+    make_node_motif(out, .data)
   }
 }
 
 #' #' @export
-#' node_bmotif_census <- function(object, normalized = FALSE){
+#' node_bmotif_census <- function(.data, normalized = FALSE){
 #'   if (!("bmotif" %in% rownames(utils::installed.packages()))) {
 #'     message("Please install package `{bmotif}`.")
-#'     out <- bmotif::node_positions(as_matrix(object), 
-#'                                   weights_method = ifelse(is_weighted(object),
+#'     out <- bmotif::node_positions(manynet::as_matrix(.data), 
+#'                                   weights_method = ifelse(manynet::is_weighted(.data),
 #'                                                           'mean_motifweights', 'none'),
 #'                                   normalisation = ifelse(normalized, 
 #'                                                          'levelsize_NAzero', 'none'))
-#'     make_node_motif(out, object)
+#'     make_node_motif(out, .data)
 #'   }
 #' }
 #' 
 #' #' @export
-#' node_igraph_census <- function(object, normalized = FALSE){
-#'     out <- igraph::motifs(as_igraph(object), 4)
-#'     if(is_labelled(object))
-#'       rownames(out) <- node_names(object)
+#' node_igraph_census <- function(.data, normalized = FALSE){
+#'     out <- igraph::motifs(manynet::as_igraph(.data), 4)
+#'     if(manynet::is_labelled(.data))
+#'       rownames(out) <- manynet::node_names(.data)
 #'     colnames(out) <- c("co-K4",
 #'                        "co-diamond",
 #'                        "co-C4",
@@ -183,7 +183,7 @@ node_quad_census <- function(object){
 #'                        "C4",
 #'                        "diamond",
 #'                        "K4")
-#'     make_node_motif(out, object)
+#'     make_node_motif(out, .data)
 #' }
 
 #' @describeIn node_census Returns the shortest path lengths
@@ -200,16 +200,16 @@ node_quad_census <- function(object){
 #' _Social Networks_ 32(3): 245-51.
 #' \doi{10.1016/j.socnet.2010.03.006}.
 #' @examples 
-#' node_path_census(ison_adolescents)
-#' node_path_census(ison_southern_women)
+#' node_path_census(manynet::ison_adolescents)
+#' node_path_census(manynet::ison_southern_women)
 #' @export
-node_path_census <- function(object){
-  if(is_weighted(object)){
-    tore <- as_matrix(object)/mean(as_matrix(object))
+node_path_census <- function(.data){
+  if(manynet::is_weighted(.data)){
+    tore <- manynet::as_matrix(.data)/mean(manynet::as_matrix(.data))
     out <- 1/tore
-  } else out <- igraph::distances(as_igraph(object))
+  } else out <- igraph::distances(manynet::as_igraph(.data))
   diag(out) <- 0
-  make_node_motif(out, object)
+  make_node_motif(out, .data)
 }
 
 #' Censuses of motifs at the network level
@@ -222,17 +222,17 @@ NULL
 
 #' @describeIn network_census Returns a census of dyad motifs in a network
 #' @examples 
-#' network_dyad_census(ison_algebra)
+#' network_dyad_census(manynet::ison_algebra)
 #' @export
-network_dyad_census <- function(object) {
-  if (is_twomode(object)) {
+network_dyad_census <- function(.data) {
+  if (manynet::is_twomode(.data)) {
     stop("A twomode or multilevel option for a dyad census is not yet implemented.")
   } else {
-    out <- suppressWarnings(igraph::dyad_census(as_igraph(object)))
+    out <- suppressWarnings(igraph::dyad_census(manynet::as_igraph(.data)))
     out <- unlist(out)
     names(out) <- c("Mutual", "Asymmetric", "Null")
-    if (!is_directed(object)) out <- out[c(1, 3)]
-    make_network_motif(out, object)
+    if (!manynet::is_directed(.data)) out <- out[c(1, 3)]
+    make_network_motif(out, .data)
   }
 }
 
@@ -241,19 +241,19 @@ network_dyad_census <- function(object) {
 #' Davis, James A., and Samuel Leinhardt. 1967. 
 #' “\href{https://files.eric.ed.gov/fulltext/ED024086.pdf}{The Structure of Positive Interpersonal Relations in Small Groups}.” 55.
 #' @examples 
-#' network_triad_census(ison_adolescents)
+#' network_triad_census(manynet::ison_adolescents)
 #' @export
-network_triad_census <- function(object) {
-  if (is_twomode(object)) {
+network_triad_census <- function(.data) {
+  if (manynet::is_twomode(.data)) {
     stop("A twomode or multilevel option for a triad census is not yet implemented.")
   } else {
-    out <- suppressWarnings(igraph::triad_census(as_igraph(object)))
+    out <- suppressWarnings(igraph::triad_census(as_igraph(.data)))
     names(out) <- c("003", "012", "102", "021D",
                     "021U", "021C", "111D", "111U",
                     "030T", "030C", "201", "120D",
                     "120U", "120C", "210", "300")
-    if (!is_directed(object)) out <- out[c(1, 2, 3, 11, 15, 16)]
-    make_network_motif(out, object)
+    if (!manynet::is_directed(.data)) out <- out[c(1, 2, 3, 11, 15, 16)]
+    make_network_motif(out, .data)
   }
 }
 
@@ -266,18 +266,19 @@ network_triad_census <- function(object) {
 #' _Network Science_ 5(2): 187–212.
 #' \doi{10.1017/nws.2017.8}
 #' @examples 
-#' marvel_friends <- to_unsigned(ison_marvel_relationships, "positive")
-#' (mixed_cen <- network_mixed_census(marvel_friends, ison_marvel_teams))
+#' marvel_friends <- manynet::to_unsigned(manynet::ison_marvel_relationships, "positive")
+#' (mixed_cen <- network_mixed_census(marvel_friends, manynet::ison_marvel_teams))
 #' @export
-network_mixed_census <- function (object, object2) {
-  if(is_twomode(object)) stop("First object should be a one-mode network")
-  if(!is_twomode(object2)) stop("Second object should be a two-mode network")
-  if(network_dims(object)[1]!=network_dims(object2)[1]) stop("Non-conformable arrays")
-  
-  m1 <- as_matrix(object)
-  m2 <- as_matrix(object2)
+network_mixed_census <- function (.data, object2) {
+  if(manynet::is_twomode(.data))
+    stop("First object should be a one-mode network")
+  if(!manynet::is_twomode(object2))
+    stop("Second object should be a two-mode network")
+  if(manynet::network_dims(.data)[1] != manynet::network_dims(object2)[1])
+    stop("Non-conformable arrays")
+  m1 <- manynet::as_matrix(.data)
+  m2 <- manynet::as_matrix(object2)
   cp <- function(m) (-m + 1)
-  
   onemode.reciprocal <- m1 * t(m1)
   onemode.forward <- m1 * cp(t(m1))
   onemode.backward <- cp(m1) * t(m1)
@@ -285,7 +286,6 @@ network_mixed_census <- function (object, object2) {
   diag(onemode.forward) <- 0
   diag(onemode.backward) <- 0
   diag(onemode.null) <- 0
-  
   bipartite.twopath <- m2 %*% t(m2)
   bipartite.null <- cp(m2) %*% cp(t(m2))
   bipartite.onestep1 <- m2 %*% cp(t(m2))
@@ -294,7 +294,6 @@ network_mixed_census <- function (object, object2) {
   diag(bipartite.null) <- 0
   diag(bipartite.onestep1) <- 0
   diag(bipartite.onestep2) <- 0
-  
   res <- c("22" = sum(onemode.reciprocal * bipartite.twopath) / 2,
            "21" = sum(onemode.forward * bipartite.twopath) / 2 + sum(onemode.backward * bipartite.twopath) / 2,
            "20" = sum(onemode.null * bipartite.twopath) / 2,
@@ -305,7 +304,7 @@ network_mixed_census <- function (object, object2) {
            "02" = sum(onemode.reciprocal * bipartite.null) / 2,
            "01" = sum(onemode.forward * bipartite.null) / 2 + sum(onemode.backward * bipartite.null) / 2,
            "00" = sum(onemode.null * bipartite.null) / 2)  
-  make_network_motif(res, object)
+  make_network_motif(res, .data)
 }
 
 #' Censuses of brokerage motifs
@@ -327,27 +326,27 @@ NULL
 #' “Structures of Mediation: A Formal Approach to Brokerage in Transaction Networks.” 
 #' _Sociological Methodology_, 19: 89-126.
 #' @examples 
-#' node_brokerage_census(ison_networkers, "Discipline")
+#' node_brokerage_census(manynet::ison_networkers, "Discipline")
 #' @export
-node_brokerage_census <- function(object, membership, standardized = FALSE){
-  out <- sna::brokerage(as_network(object), node_attribute(object, membership))
+node_brokerage_census <- function(.data, membership, standardized = FALSE){
+  out <- sna::brokerage(manynet::as_network(.data),
+                        manynet::node_attribute(.data, membership))
   out <- if(standardized) out$z.nli else out$raw.nli
   colnames(out) <- c("Coordinator", "Itinerant", "Gatekeeper", 
                      "Representative", "Liaison", "Total")
-  make_node_motif(out, object)
+  make_node_motif(out, .data)
 }
 
 #' @describeIn brokerage_census Returns the Gould-Fernandez brokerage
 #'   roles in a network.
 #' @examples 
-#' network_brokerage_census(ison_networkers, "Discipline")
+#' network_brokerage_census(manynet::ison_networkers, "Discipline")
 #' @export
-network_brokerage_census <- function(object, membership, standardized = FALSE){
-  out <- sna::brokerage(as_network(object), node_attribute(object, membership))
+network_brokerage_census <- function(.data, membership, standardized = FALSE){
+  out <- sna::brokerage(manynet::as_network(.data),
+                        manynet::node_attribute(.data, membership))
   out <- if(standardized) out$z.gli else out$raw.gli
   names(out) <- c("Coordinator", "Itinerant", "Gatekeeper", 
                      "Representative", "Liaison", "Total")
-  make_network_motif(out, object)
+  make_network_motif(out, .data)
 }
-
-
