@@ -20,9 +20,9 @@ test_that("tie_is_bridge works", {
 })
 
 test_that("tie_is_max works", {
-  expect_equal(length(tie_is_max(tie_betweenness(ison_brandes))), network_ties(ison_brandes))
-  expect_equal(sum(tie_is_max(tie_betweenness(ison_brandes)) == TRUE), 1)
-  expect_s3_class(tie_is_max(tie_betweenness(ison_brandes)), "logical")
+  expect_equal(length(tie_is_max(tie_betweenness(graph1))), network_ties(graph1))
+  expect_equal(sum(tie_is_max(tie_betweenness(graph1)) == TRUE), 1)
+  expect_s3_class(tie_is_max(tie_betweenness(graph1)), "logical")
 })
 
 test_that("tie_is_min works", {
